[nautilus-actions/file-manager-actions] na_gconf_utils_xxx are renamed to fma_gconf_utils_xxx



commit 3615e9863809f1bb20f9f61435ad499e0dc32707
Author: Pierre Wieser <pwieser trychlos org>
Date:   Mon Sep 7 21:56:28 2015 +0200

    na_gconf_utils_xxx are renamed to fma_gconf_utils_xxx

 src/api/Makefile.am                              |    2 +-
 src/api/fma-gconf-monitor.h                      |    6 +-
 src/api/fma-gconf-utils.h                        |   79 ++++++++++++++
 src/api/na-gconf-utils.h                         |   79 --------------
 src/api/na-icontext.h                            |    6 +-
 src/core/Makefile.am                             |    2 +-
 src/core/fma-data-boxed.c                        |    2 +-
 src/core/{na-gconf-utils.c => fma-gconf-utils.c} |  122 +++++++++++-----------
 src/core/na-updater.c                            |    2 +-
 src/io-gconf/nagp-reader.c                       |   30 +++---
 src/io-gconf/nagp-writer.c                       |   20 ++--
 src/io-xml/naxml-reader.c                        |    2 +-
 src/nact/nact-providers-list.c                   |    2 +-
 13 files changed, 177 insertions(+), 177 deletions(-)
---
diff --git a/src/api/Makefile.am b/src/api/Makefile.am
index 4993b5f..c01c9fb 100644
--- a/src/api/Makefile.am
+++ b/src/api/Makefile.am
@@ -43,7 +43,7 @@ api_include_HEADERS = \
        fma-data-def.h                                                                          \
        fma-data-types.h                                                                                \
        fma-gconf-monitor.h                                                                     \
-       na-gconf-utils.h                                                                        \
+       fma-gconf-utils.h                                                                       \
        na-icontext.h                                                                           \
        na-iduplicable.h                                                                        \
        na-ifactory-object.h                                                            \
diff --git a/src/api/fma-gconf-monitor.h b/src/api/fma-gconf-monitor.h
index 6599a0d..cbbc4bc 100644
--- a/src/api/fma-gconf-monitor.h
+++ b/src/api/fma-gconf-monitor.h
@@ -27,8 +27,8 @@
  *   ... and many others (see AUTHORS)
  */
 
-#ifndef __FILE_MANAGER_ACTIONS_API_FMA_GCONF_MONITOR_H__
-#define __FILE_MANAGER_ACTIONS_API_FMA_GCONF_MONITOR_H__
+#ifndef __FILE_MANAGER_ACTIONS_API_GCONF_MONITOR_H__
+#define __FILE_MANAGER_ACTIONS_API_GCONF_MONITOR_H__
 
 #ifdef HAVE_GCONF
 #ifdef NA_ENABLE_DEPRECATED
@@ -85,4 +85,4 @@ G_END_DECLS
 
 #endif /* NA_ENABLE_DEPRECATED */
 #endif /* HAVE_GCONF */
-#endif /* __FILE_MANAGER_ACTIONS_API_FMA_GCONF_MONITOR_H__ */
+#endif /* __FILE_MANAGER_ACTIONS_API_GCONF_MONITOR_H__ */
diff --git a/src/api/fma-gconf-utils.h b/src/api/fma-gconf-utils.h
new file mode 100644
index 0000000..049d960
--- /dev/null
+++ b/src/api/fma-gconf-utils.h
@@ -0,0 +1,79 @@
+/*
+ * FileManager-Actions
+ * A file-manager extension which offers configurable context menu actions.
+ *
+ * Copyright (C) 2005 The GNOME Foundation
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2015 Pierre Wieser and others (see AUTHORS)
+ *
+ * FileManager-Actions is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of
+ * the License, or (at your option) any later version.
+ *
+ * FileManager-Actions is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with FileManager-Actions; see the file COPYING. If not, see
+ * <http://www.gnu.org/licenses/>.
+ *
+ * Authors:
+ *   Frederic Ruaudel <grumz grumz net>
+ *   Rodrigo Moya <rodrigo gnome-db org>
+ *   Pierre Wieser <pwieser trychlos org>
+ *   ... and many others (see AUTHORS)
+ */
+
+#ifndef __FILE_MANAGER_ACTIONS_API_GCONF_UTILS_H__
+#define __FILE_MANAGER_ACTIONS_API_GCONF_UTILS_H__
+
+#ifdef HAVE_GCONF
+/**
+ * SECTION: gconf-utils
+ * @title: GConf Misc
+ * @short_description: The GConf Library Utilities
+ * @include: runtime/fma-gconf-utils.h
+ *
+ * Starting with FileManager-Actions 3.1.0, GConf, whether it is used as a
+ * preference storage subsystem or as an I/O provider, is deprecated.
+ */
+
+#include <gconf/gconf-client.h>
+
+G_BEGIN_DECLS
+
+GSList  *fma_gconf_utils_get_subdirs( GConfClient *gconf, const gchar *path );
+void     fma_gconf_utils_free_subdirs( GSList *subdirs );
+
+gboolean fma_gconf_utils_has_entry  ( GSList *entries, const gchar *entry );
+GSList  *fma_gconf_utils_get_entries( GConfClient *gconf, const gchar *path );
+gboolean fma_gconf_utils_get_bool_from_entries       ( GSList *entries, const gchar *entry, gboolean *value 
);
+gboolean fma_gconf_utils_get_string_from_entries     ( GSList *entries, const gchar *entry, gchar **value );
+gboolean fma_gconf_utils_get_string_list_from_entries( GSList *entries, const gchar *entry, GSList **value );
+void     fma_gconf_utils_dump_entries                ( GSList *entries );
+void     fma_gconf_utils_free_entries                ( GSList *entries );
+
+gboolean fma_gconf_utils_read_bool        ( GConfClient *gconf, const gchar *path, gboolean use_schema, 
gboolean default_value );
+gint     fma_gconf_utils_read_int         ( GConfClient *gconf, const gchar *path, gboolean use_schema, gint 
default_value );
+gchar   *fma_gconf_utils_read_string      ( GConfClient *gconf, const gchar *path, gboolean use_schema, 
const gchar *default_value );
+GSList  *fma_gconf_utils_read_string_list ( GConfClient *gconf, const gchar *path );
+
+/* Writing in GConf is deprecated since 3.1.0
+ */
+#ifdef NA_ENABLE_DEPRECATED
+gboolean fma_gconf_utils_write_bool       ( GConfClient *gconf, const gchar *path, gboolean value, gchar 
**message );
+gboolean fma_gconf_utils_write_int        ( GConfClient *gconf, const gchar *path, gint value, gchar 
**message );
+gboolean fma_gconf_utils_write_string     ( GConfClient *gconf, const gchar *path, const gchar *value, gchar 
**message );
+gboolean fma_gconf_utils_write_string_list( GConfClient *gconf, const gchar *path, GSList *value, gchar 
**message );
+gboolean fma_gconf_utils_remove_entry     ( GConfClient *gconf, const gchar *path, gchar **message );
+GSList  *fma_gconf_utils_slist_from_string( const gchar *value );
+gchar   *fma_gconf_utils_slist_to_string  ( GSList *slist );
+#endif /* NA_ENABLE_DEPRECATED */
+
+G_END_DECLS
+
+#endif /* HAVE_GCONF */
+#endif /* __FILE_MANAGER_ACTIONS_API_GCONF_UTILS_H__ */
diff --git a/src/api/na-icontext.h b/src/api/na-icontext.h
index 8a2ab26..bb7c0b2 100644
--- a/src/api/na-icontext.h
+++ b/src/api/na-icontext.h
@@ -27,8 +27,8 @@
  *   ... and many others (see AUTHORS)
  */
 
-#ifndef __FILE_MANAGER_ACTIONS_API_NA_ICONTEXT_H__
-#define __FILE_MANAGER_ACTIONS_API_NA_ICONTEXT_H__
+#ifndef __FILE_MANAGER_ACTIONS_API_ICONTEXT_H__
+#define __FILE_MANAGER_ACTIONS_API_ICONTEXT_H__
 
 /**
  * SECTION: icontext
@@ -109,4 +109,4 @@ void     na_icontext_replace_folder  ( NAIContext *context, const gchar *old, co
 
 G_END_DECLS
 
-#endif /* __FILE_MANAGER_ACTIONS_API_NA_ICONTEXT_H__ */
+#endif /* __FILE_MANAGER_ACTIONS_API_ICONTEXT_H__ */
diff --git a/src/core/Makefile.am b/src/core/Makefile.am
index 6a4d19d..b0f35cf 100644
--- a/src/core/Makefile.am
+++ b/src/core/Makefile.am
@@ -71,7 +71,7 @@ libna_core_la_SOURCES = \
        na-gconf-migration.c                                                            \
        na-gconf-migration.h                                                            \
        fma-gconf-monitor.c                                                                     \
-       na-gconf-utils.c                                                                        \
+       fma-gconf-utils.c                                                                       \
        na-gnome-vfs-uri.c                                                                      \
        na-gnome-vfs-uri.h                                                                      \
        na-gtk-utils.c                                                                          \
diff --git a/src/core/fma-data-boxed.c b/src/core/fma-data-boxed.c
index c50bf9b..338076d 100644
--- a/src/core/fma-data-boxed.c
+++ b/src/core/fma-data-boxed.c
@@ -36,7 +36,7 @@
 #include <string.h>
 
 #include <api/fma-core-utils.h>
-#include <api/na-gconf-utils.h>
+#include <api/fma-gconf-utils.h>
 #include <api/fma-data-def.h>
 #include <api/fma-data-types.h>
 #include <api/fma-data-boxed.h>
diff --git a/src/core/na-updater.c b/src/core/na-updater.c
index 18f64e5..fb452ed 100644
--- a/src/core/na-updater.c
+++ b/src/core/na-updater.c
@@ -32,7 +32,7 @@
 #endif
 
 #include <api/fma-core-utils.h>
-#include <api/na-gconf-utils.h>
+#include <api/fma-gconf-utils.h>
 #include <api/na-object-api.h>
 
 #include "na-io-provider.h"
diff --git a/src/io-gconf/nagp-reader.c b/src/io-gconf/nagp-reader.c
index 8fd3450..af575aa 100644
--- a/src/io-gconf/nagp-reader.c
+++ b/src/io-gconf/nagp-reader.c
@@ -39,7 +39,7 @@
 #include <api/na-iio-provider.h>
 #include <api/na-object-api.h>
 #include <api/fma-core-utils.h>
-#include <api/na-gconf-utils.h>
+#include <api/fma-gconf-utils.h>
 
 #include "nagp-gconf-provider.h"
 #include "nagp-keys.h"
@@ -87,7 +87,7 @@ nagp_iio_provider_read_items( const NAIIOProvider *provider, GSList **messages )
 
        if( !self->private->dispose_has_run ){
 
-               listpath = na_gconf_utils_get_subdirs( self->private->gconf, NAGP_CONFIGURATIONS_PATH );
+               listpath = fma_gconf_utils_get_subdirs( self->private->gconf, NAGP_CONFIGURATIONS_PATH );
 
                for( ip = listpath ; ip ; ip = ip->next ){
 
@@ -98,7 +98,7 @@ nagp_iio_provider_read_items( const NAIIOProvider *provider, GSList **messages )
                        }
                }
 
-               na_gconf_utils_free_subdirs( listpath );
+               fma_gconf_utils_free_subdirs( listpath );
        }
 
        g_debug( "%s: count=%d", thisfn, g_list_length( items_list ));
@@ -124,7 +124,7 @@ read_item( NagpGConfProvider *provider, const gchar *path, GSList **messages )
        g_return_val_if_fail( !provider->private->dispose_has_run, NULL );
 
        full_path = gconf_concat_dir_and_key( path, NAGP_ENTRY_TYPE );
-       type = na_gconf_utils_read_string( provider->private->gconf, full_path, TRUE, NAGP_VALUE_TYPE_ACTION 
);
+       type = fma_gconf_utils_read_string( provider->private->gconf, full_path, TRUE, NAGP_VALUE_TYPE_ACTION 
);
        g_free( full_path );
        item = NULL;
 
@@ -149,8 +149,8 @@ read_item( NagpGConfProvider *provider, const gchar *path, GSList **messages )
 
                data = g_new0( ReaderData, 1 );
                data->path = ( gchar * ) path;
-               data->entries = na_gconf_utils_get_entries( provider->private->gconf, path );
-               na_gconf_utils_dump_entries( data->entries );
+               data->entries = fma_gconf_utils_get_entries( provider->private->gconf, path );
+               fma_gconf_utils_dump_entries( data->entries );
 
                na_ifactory_provider_read_item(
                                NA_IFACTORY_PROVIDER( provider ),
@@ -158,7 +158,7 @@ read_item( NagpGConfProvider *provider, const gchar *path, GSList **messages )
                                NA_IFACTORY_OBJECT( item ),
                                messages );
 
-               na_gconf_utils_free_entries( data->entries );
+               fma_gconf_utils_free_entries( data->entries );
                g_free( data );
        }
 
@@ -289,7 +289,7 @@ read_done_action_read_profiles( const NAIFactoryProvider *provider, NAObjectActi
 
        data->parent = NA_OBJECT_ITEM( action );
        order = na_object_get_items_slist( action );
-       list_profiles = na_gconf_utils_get_subdirs( NAGP_GCONF_PROVIDER( provider )->private->gconf, 
data->path );
+       list_profiles = fma_gconf_utils_get_subdirs( NAGP_GCONF_PROVIDER( provider )->private->gconf, 
data->path );
 
        /* read profiles in the specified order
         * as a protection against bugs in NACT, we check that profile has not
@@ -343,7 +343,7 @@ read_done_action_load_profile( const NAIFactoryProvider *provider, ReaderData *d
        profile_data = g_new0( ReaderData, 1 );
        profile_data->parent = data->parent;
        profile_data->path = ( gchar * ) path;
-       profile_data->entries = na_gconf_utils_get_entries( NAGP_GCONF_PROVIDER( provider )->private->gconf, 
path );
+       profile_data->entries = fma_gconf_utils_get_entries( NAGP_GCONF_PROVIDER( provider )->private->gconf, 
path );
 
        na_ifactory_provider_read_item(
                        NA_IFACTORY_PROVIDER( provider ),
@@ -351,7 +351,7 @@ read_done_action_load_profile( const NAIFactoryProvider *provider, ReaderData *d
                        NA_IFACTORY_OBJECT( profile ),
                        messages );
 
-       na_gconf_utils_free_entries( profile_data->entries );
+       fma_gconf_utils_free_entries( profile_data->entries );
        g_free( profile_data );
 }
 
@@ -367,7 +367,7 @@ get_boxed_from_path( const NagpGConfProvider *provider, const gchar *path, Reade
        gint int_value;
 
        boxed = NULL;
-       have_entry = na_gconf_utils_has_entry( reader_data->entries, def->gconf_entry );
+       have_entry = fma_gconf_utils_has_entry( reader_data->entries, def->gconf_entry );
        g_debug( "%s: entry=%s, have_entry=%s", thisfn, def->gconf_entry, have_entry ? "True":"False" );
 
        if( have_entry ){
@@ -378,24 +378,24 @@ get_boxed_from_path( const NagpGConfProvider *provider, const gchar *path, Reade
 
                        case NA_DATA_TYPE_STRING:
                        case NA_DATA_TYPE_LOCALE_STRING:
-                               str_value = na_gconf_utils_read_string( provider->private->gconf, entry_path, 
TRUE, NULL );
+                               str_value = fma_gconf_utils_read_string( provider->private->gconf, 
entry_path, TRUE, NULL );
                                fma_boxed_set_from_string( FMA_BOXED( boxed ), str_value );
                                g_free( str_value );
                                break;
 
                        case NA_DATA_TYPE_BOOLEAN:
-                               bool_value = na_gconf_utils_read_bool( provider->private->gconf, entry_path, 
TRUE, FALSE );
+                               bool_value = fma_gconf_utils_read_bool( provider->private->gconf, entry_path, 
TRUE, FALSE );
                                fma_boxed_set_from_void( FMA_BOXED( boxed ), GUINT_TO_POINTER( bool_value ));
                                break;
 
                        case NA_DATA_TYPE_STRING_LIST:
-                               slist_value = na_gconf_utils_read_string_list( provider->private->gconf, 
entry_path );
+                               slist_value = fma_gconf_utils_read_string_list( provider->private->gconf, 
entry_path );
                                fma_boxed_set_from_void( FMA_BOXED( boxed ), slist_value );
                                fma_core_utils_slist_free( slist_value );
                                break;
 
                        case NA_DATA_TYPE_UINT:
-                               int_value = na_gconf_utils_read_int( provider->private->gconf, entry_path, 
TRUE, 0 );
+                               int_value = fma_gconf_utils_read_int( provider->private->gconf, entry_path, 
TRUE, 0 );
                                fma_boxed_set_from_void( FMA_BOXED( boxed ), GUINT_TO_POINTER( int_value ));
                                break;
 
diff --git a/src/io-gconf/nagp-writer.c b/src/io-gconf/nagp-writer.c
index 0593b6f..a423eb4 100644
--- a/src/io-gconf/nagp-writer.c
+++ b/src/io-gconf/nagp-writer.c
@@ -39,7 +39,7 @@
 #include <api/na-ifactory-provider.h>
 #include <api/na-object-api.h>
 #include <api/fma-core-utils.h>
-#include <api/na-gconf-utils.h>
+#include <api/fma-gconf-utils.h>
 
 #include "nagp-gconf-provider.h"
 #include "nagp-writer.h"
@@ -91,11 +91,11 @@ nagp_iio_provider_is_able_to_write( const NAIIOProvider *provider )
 
        if( !self->private->dispose_has_run ){
 
-               if( !na_gconf_utils_write_string( self->private->gconf, path, "foo", NULL )){
+               if( !fma_gconf_utils_write_string( self->private->gconf, path, "foo", NULL )){
                        able_to = FALSE;
 
                } else {
-                       gchar *str = na_gconf_utils_read_string( self->private->gconf, path, FALSE, NULL );
+                       gchar *str = fma_gconf_utils_read_string( self->private->gconf, path, FALSE, NULL );
                        if( strcmp( str, "foo" )){
                                able_to = FALSE;
 
@@ -252,7 +252,7 @@ write_start_write_type( NagpGConfProvider *provider, NAObjectItem *item )
        id = na_object_get_id( item );
        path = g_strdup_printf( "%s/%s/%s", NAGP_CONFIGURATIONS_PATH, id, NAGP_ENTRY_TYPE );
 
-       na_gconf_utils_write_string(
+       fma_gconf_utils_write_string(
                        provider->private->gconf,
                        path,
                        NA_IS_OBJECT_ACTION( item ) ? NAGP_VALUE_TYPE_ACTION : NAGP_VALUE_TYPE_MENU,
@@ -272,7 +272,7 @@ write_start_write_version( NagpGConfProvider *provider, NAObjectItem *item )
        path = g_strdup_printf( "%s/%s/%s", NAGP_CONFIGURATIONS_PATH, id, NAGP_ENTRY_IVERSION );
 
        iversion = na_object_get_iversion( item );
-       na_gconf_utils_write_int( provider->private->gconf, path, iversion, NULL );
+       fma_gconf_utils_write_int( provider->private->gconf, path, iversion, NULL );
 
        g_free( path );
        g_free( id );
@@ -324,7 +324,7 @@ nagp_writer_write_data( const NAIFactoryProvider *provider, void *writer_data,
 
                        case NA_DATA_TYPE_STRING:
                                str_value = fma_boxed_get_string( FMA_BOXED( boxed ));
-                               na_gconf_utils_write_string( gconf, path, str_value, &msg );
+                               fma_gconf_utils_write_string( gconf, path, str_value, &msg );
                                if( msg ){
                                        *messages = g_slist_append( *messages, msg );
                                        code = NA_IIO_PROVIDER_CODE_WRITE_ERROR;
@@ -334,7 +334,7 @@ nagp_writer_write_data( const NAIFactoryProvider *provider, void *writer_data,
 
                        case NA_DATA_TYPE_LOCALE_STRING:
                                str_value = fma_boxed_get_string( FMA_BOXED( boxed ));
-                               na_gconf_utils_write_string( gconf, path, str_value, &msg );
+                               fma_gconf_utils_write_string( gconf, path, str_value, &msg );
                                if( msg ){
                                        *messages = g_slist_append( *messages, msg );
                                        code = NA_IIO_PROVIDER_CODE_WRITE_ERROR;
@@ -344,7 +344,7 @@ nagp_writer_write_data( const NAIFactoryProvider *provider, void *writer_data,
 
                        case NA_DATA_TYPE_BOOLEAN:
                                bool_value = GPOINTER_TO_UINT( fma_boxed_get_as_void( FMA_BOXED( boxed )));
-                               na_gconf_utils_write_bool( gconf, path, bool_value, &msg );
+                               fma_gconf_utils_write_bool( gconf, path, bool_value, &msg );
                                if( msg ){
                                        *messages = g_slist_append( *messages, msg );
                                        code = NA_IIO_PROVIDER_CODE_WRITE_ERROR;
@@ -353,7 +353,7 @@ nagp_writer_write_data( const NAIFactoryProvider *provider, void *writer_data,
 
                        case NA_DATA_TYPE_STRING_LIST:
                                slist_value = ( GSList * ) fma_boxed_get_as_void( FMA_BOXED( boxed ));
-                               na_gconf_utils_write_string_list( gconf, path, slist_value, &msg );
+                               fma_gconf_utils_write_string_list( gconf, path, slist_value, &msg );
                                if( msg ){
                                        *messages = g_slist_append( *messages, msg );
                                        code = NA_IIO_PROVIDER_CODE_WRITE_ERROR;
@@ -363,7 +363,7 @@ nagp_writer_write_data( const NAIFactoryProvider *provider, void *writer_data,
 
                        case NA_DATA_TYPE_UINT:
                                uint_value = GPOINTER_TO_UINT( fma_boxed_get_as_void( FMA_BOXED( boxed )));
-                               na_gconf_utils_write_int( gconf, path, uint_value, &msg );
+                               fma_gconf_utils_write_int( gconf, path, uint_value, &msg );
                                if( msg ){
                                        *messages = g_slist_append( *messages, msg );
                                        code = NA_IIO_PROVIDER_CODE_WRITE_ERROR;
diff --git a/src/io-xml/naxml-reader.c b/src/io-xml/naxml-reader.c
index 4d18e8f..2f57205 100644
--- a/src/io-xml/naxml-reader.c
+++ b/src/io-xml/naxml-reader.c
@@ -36,7 +36,7 @@
 #include <string.h>
 
 #include <api/fma-core-utils.h>
-#include <api/na-gconf-utils.h>
+#include <api/fma-gconf-utils.h>
 #include <api/fma-data-types.h>
 #include <api/na-ifactory-provider.h>
 #include <api/na-object-api.h>
diff --git a/src/nact/nact-providers-list.c b/src/nact/nact-providers-list.c
index 24edc62..9a8b296 100644
--- a/src/nact/nact-providers-list.c
+++ b/src/nact/nact-providers-list.c
@@ -34,7 +34,7 @@
 #include <glib/gi18n.h>
 
 #include <api/fma-core-utils.h>
-#include <api/na-gconf-utils.h>
+#include <api/fma-gconf-utils.h>
 #include <api/na-object-api.h>
 
 #include <core/na-io-provider.h>


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/core/na-gconf-utils.c b/src/core/fma-gconf-utils.c
similarity index 82%
rename from src/core/na-gconf-utils.c
rename to src/core/fma-gconf-utils.c
index 19ba2ab..86231e6 100644
--- a/src/core/na-gconf-utils.c
+++ b/src/core/fma-gconf-utils.c
@@ -36,7 +36,7 @@
 #include <string.h>
 
 #include <api/fma-core-utils.h>
-#include <api/na-gconf-utils.h>
+#include <api/fma-gconf-utils.h>
 
 static void        dump_entry( GConfEntry *entry, void *user_data );
 static GConfValue *read_value( GConfClient *gconf, const gchar *path, gboolean use_schema, GConfValueType 
type );
@@ -46,20 +46,20 @@ static gboolean    sync_gconf( GConfClient *gconf, gchar **message );
 #endif /* NA_ENABLE_DEPRECATED */
 
 /**
- * na_gconf_utils_get_subdirs:
+ * fma_gconf_utils_get_subdirs:
  * @gconf: a GConfClient instance.
  * @path: a full path to be read.
  *
  * Returns: a list of full path subdirectories.
  *
  * The returned list should be na_gconf_utils_free_subdirs() by the caller.
  *
  * Since: 2.30
  */
 GSList *
-na_gconf_utils_get_subdirs( GConfClient *gconf, const gchar *path )
+fma_gconf_utils_get_subdirs( GConfClient *gconf, const gchar *path )
 {
-       static const gchar *thisfn = "na_gconf_utils_get_subdirs";
+       static const gchar *thisfn = "fma_gconf_utils_get_subdirs";
        GError *error = NULL;
        GSList *list_subdirs;
 
@@ -75,22 +75,22 @@ na_gconf_utils_get_subdirs( GConfClient *gconf, const gchar *path )
 }
 
 /**
  * na_gconf_utils_free_subdirs:
  * @subdirs: the subdirectory list as returned from na_gconf_utils_get_subdirs().
  *
  * Release the list.
  *
  * Since: 2.30
  */
 void
-na_gconf_utils_free_subdirs( GSList *subdirs )
+fma_gconf_utils_free_subdirs( GSList *subdirs )
 {
        fma_core_utils_slist_free( subdirs );
 }
 
 /**
  * na_gconf_utils_has_entry:
  * @entries: the list of entries as returned by na_gconf_utils_get_entries().
  * @entry: the entry to be tested.
  *
  * Returns: %TRUE if the given @entry exists in the specified @entries,
@@ -99,7 +99,7 @@ na_gconf_utils_free_subdirs( GSList *subdirs )
  * Since: 2.30
  */
 gboolean
-na_gconf_utils_has_entry( GSList *entries, const gchar *entry )
+fma_gconf_utils_has_entry( GSList *entries, const gchar *entry )
 {
        GSList *ie;
 
@@ -116,7 +116,7 @@ na_gconf_utils_has_entry( GSList *entries, const gchar *entry )
 }
 
 /**
- * na_gconf_utils_get_entries:
+ * fma_gconf_utils_get_entries:
  * @gconf: a  GConfClient instance.
  * @path: a full path to be read.
  *
@@ -126,14 +126,14 @@ na_gconf_utils_has_entry( GSList *entries, const gchar *entry )
  *
  * The returned list is not recursive : it contains only the immediate
  * children of @path. To free the returned list, call
- * na_gconf_utils_free_entries().
+ * fma_gconf_utils_free_entries().
  *
  * Since: 2.30
  */
 GSList *
-na_gconf_utils_get_entries( GConfClient *gconf, const gchar *path )
+fma_gconf_utils_get_entries( GConfClient *gconf, const gchar *path )
 {
-       static const gchar *thisfn = "na_gconf_utils_get_entries";
+       static const gchar *thisfn = "fma_gconf_utils_get_entries";
        GError *error = NULL;
        GSList *list_entries;
 
@@ -149,8 +149,8 @@ na_gconf_utils_get_entries( GConfClient *gconf, const gchar *path )
 }
 
 /**
  * na_gconf_utils_get_bool_from_entries:
  * @entries: a list of #GConfEntry as returned by na_gconf_utils_get_entries().
  * @entry: the searched entry.
  * @value: a pointer to a gboolean to be set to the found value.
  *
@@ -162,7 +162,7 @@ na_gconf_utils_get_entries( GConfClient *gconf, const gchar *path )
  * Since: 2.30
  */
 gboolean
-na_gconf_utils_get_bool_from_entries( GSList *entries, const gchar *entry, gboolean *value )
+fma_gconf_utils_get_bool_from_entries( GSList *entries, const gchar *entry, gboolean *value )
 {
        GSList *ip;
        GConfEntry *gconf_entry;
@@ -196,8 +196,8 @@ na_gconf_utils_get_bool_from_entries( GSList *entries, const gchar *entry, gbool
 }
 
 /**
  * na_gconf_utils_get_string_from_entries:
  * @entries: a list of #GConfEntry as returned by na_gconf_utils_get_entries().
  * @entry: the searched entry.
  * @value: a pointer to a gchar * to be set to the found value.
  *
@@ -211,7 +211,7 @@ na_gconf_utils_get_bool_from_entries( GSList *entries, const gchar *entry, gbool
  * Since: 2.30
  */
 gboolean
-na_gconf_utils_get_string_from_entries( GSList *entries, const gchar *entry, gchar **value )
+fma_gconf_utils_get_string_from_entries( GSList *entries, const gchar *entry, gchar **value )
 {
        GSList *ip;
        GConfEntry *gconf_entry;
@@ -245,8 +245,8 @@ na_gconf_utils_get_string_from_entries( GSList *entries, const gchar *entry, gch
 }
 
 /**
  * na_gconf_utils_get_string_list_from_entries:
  * @entries: a list of #GConfEntry as returned by na_gconf_utils_get_entries().
  * @entry: the searched entry.
  * @value: a pointer to a GSList * to be set to the found value.
  *
@@ -261,7 +261,7 @@ na_gconf_utils_get_string_from_entries( GSList *entries, const gchar *entry, gch
  * Since: 2.30
  */
 gboolean
-na_gconf_utils_get_string_list_from_entries( GSList *entries, const gchar *entry, GSList **value )
+fma_gconf_utils_get_string_list_from_entries( GSList *entries, const gchar *entry, GSList **value )
 {
        GSList *ip, *iv;
        GConfEntry *gconf_entry;
@@ -299,15 +299,15 @@ na_gconf_utils_get_string_list_from_entries( GSList *entries, const gchar *entry
 }
 
 /**
  * na_gconf_utils_dump_entries:
  * @entries: a list of #GConfEntry as returned by na_gconf_utils_get_entries().
  *
  * Dumps the content of the entries.
  *
  * Since: 2.30
  */
 void
-na_gconf_utils_dump_entries( GSList *entries )
+fma_gconf_utils_dump_entries( GSList *entries )
 {
        g_slist_foreach( entries, ( GFunc ) dump_entry, NULL );
 }
@@ -315,7 +315,7 @@ na_gconf_utils_dump_entries( GSList *entries )
 static void
 dump_entry( GConfEntry *entry, void *user_data )
 {
-       static const gchar *thisfn = "na_gconf_utils_dump_entry";
+       static const gchar *thisfn = "fma_gconf_utils_dump_entry";
        gchar *str = NULL;
        gboolean str_free = FALSE;
        GSList *value_list, *it;
@@ -383,22 +383,22 @@ dump_entry( GConfEntry *entry, void *user_data )
 }
 
 /**
  * na_gconf_utils_free_entries:
  * @entries: a list of #GConfEntry as returned by na_gconf_utils_get_entries().
  *
  * Releases the provided list.
  *
  * Since: 2.30
  */
 void
-na_gconf_utils_free_entries( GSList *entries )
+fma_gconf_utils_free_entries( GSList *entries )
 {
        g_slist_foreach( entries, ( GFunc ) gconf_entry_unref, NULL );
        g_slist_free( entries );
 }
 
 /**
- * na_gconf_utils_read_bool:
+ * fma_gconf_utils_read_bool:
  * @gconf: a GConfClient instance.
  * @path: the full path to the key.
  * @use_schema: whether to use the default value from schema, or not.
@@ -410,7 +410,7 @@ na_gconf_utils_free_entries( GSList *entries )
  * Since: 2.30
  */
 gboolean
-na_gconf_utils_read_bool( GConfClient *gconf, const gchar *path, gboolean use_schema, gboolean default_value 
)
+fma_gconf_utils_read_bool( GConfClient *gconf, const gchar *path, gboolean use_schema, gboolean 
default_value )
 {
        GConfValue *value;
        gboolean ret;
@@ -429,7 +429,7 @@ na_gconf_utils_read_bool( GConfClient *gconf, const gchar *path, gboolean use_sc
 }
 
 /**
- * na_gconf_utils_read_int:
+ * fma_gconf_utils_read_int:
  * @gconf: a GConfClient instance.
  * @path: the full path to the key.
  * @use_schema: whether to use the default value from schema, or not.
@@ -441,7 +441,7 @@ na_gconf_utils_read_bool( GConfClient *gconf, const gchar *path, gboolean use_sc
  * Since: 2.30
  */
 gint
-na_gconf_utils_read_int( GConfClient *gconf, const gchar *path, gboolean use_schema, gint default_value )
+fma_gconf_utils_read_int( GConfClient *gconf, const gchar *path, gboolean use_schema, gint default_value )
 {
        GConfValue *value = NULL;
        gint ret;
@@ -461,7 +461,7 @@ na_gconf_utils_read_int( GConfClient *gconf, const gchar *path, gboolean use_sch
 }
 
 /**
- * na_gconf_utils_read_string:
+ * fma_gconf_utils_read_string:
  * @gconf: a GConfClient instance.
  * @path: the full path to the key.
  * @use_schema: whether to use the default value from schema, or not.
@@ -474,7 +474,7 @@ na_gconf_utils_read_int( GConfClient *gconf, const gchar *path, gboolean use_sch
  * Since: 2.30
  */
 gchar *
-na_gconf_utils_read_string( GConfClient *gconf, const gchar *path, gboolean use_schema, const gchar 
*default_value )
+fma_gconf_utils_read_string( GConfClient *gconf, const gchar *path, gboolean use_schema, const gchar 
*default_value )
 {
        GConfValue *value = NULL;
        gchar *result;
@@ -495,7 +495,7 @@ na_gconf_utils_read_string( GConfClient *gconf, const gchar *path, gboolean use_
 }
 
 /**
- * na_gconf_utils_read_string_list:
+ * fma_gconf_utils_read_string_list:
  * @gconf: a GConfClient instance.
  * @path: the full path to the key to be read.
  *
@@ -507,9 +507,9 @@ na_gconf_utils_read_string( GConfClient *gconf, const gchar *path, gboolean use_
  * Since: 2.30
  */
 GSList *
-na_gconf_utils_read_string_list( GConfClient *gconf, const gchar *path )
+fma_gconf_utils_read_string_list( GConfClient *gconf, const gchar *path )
 {
-       static const gchar *thisfn = "na_gconf_utils_read_string_list";
+       static const gchar *thisfn = "fma_gconf_utils_read_string_list";
        GError *error = NULL;
        GSList *list_strings;
 
@@ -528,7 +528,7 @@ na_gconf_utils_read_string_list( GConfClient *gconf, const gchar *path )
 
 #ifdef NA_ENABLE_DEPRECATED
 /**
- * na_gconf_utils_write_bool:
+ * fma_gconf_utils_write_bool:
  * @gconf: a GConfClient instance.
  * @path: the full path to the key.
  * @value: the value to be written.
@@ -545,9 +545,9 @@ na_gconf_utils_read_string_list( GConfClient *gconf, const gchar *path )
  * Deprecated: 3.1
  */
 gboolean
-na_gconf_utils_write_bool( GConfClient *gconf, const gchar *path, gboolean value, gchar **message )
+fma_gconf_utils_write_bool( GConfClient *gconf, const gchar *path, gboolean value, gchar **message )
 {
-       static const gchar *thisfn = "na_gconf_utils_write_bool";
+       static const gchar *thisfn = "fma_gconf_utils_write_bool";
        gboolean ret = TRUE;
        GError *error = NULL;
 
@@ -566,7 +566,7 @@ na_gconf_utils_write_bool( GConfClient *gconf, const gchar *path, gboolean value
 }
 
 /**
- * na_gconf_utils_write_int:
+ * fma_gconf_utils_write_int:
  * @gconf: a GConfClient instance.
  * @path: the full path to the key.
  * @value: the value to be written.
@@ -583,9 +583,9 @@ na_gconf_utils_write_bool( GConfClient *gconf, const gchar *path, gboolean value
  * Deprecated: 3.1
  */
 gboolean
-na_gconf_utils_write_int( GConfClient *gconf, const gchar *path, gint value, gchar **message )
+fma_gconf_utils_write_int( GConfClient *gconf, const gchar *path, gint value, gchar **message )
 {
-       static const gchar *thisfn = "na_gconf_utils_write_int";
+       static const gchar *thisfn = "fma_gconf_utils_write_int";
        gboolean ret = TRUE;
        GError *error = NULL;
 
@@ -604,7 +604,7 @@ na_gconf_utils_write_int( GConfClient *gconf, const gchar *path, gint value, gch
 }
 
 /**
- * na_gconf_utils_write_string:
+ * fma_gconf_utils_write_string:
  * @gconf: a GConfClient instance.
  * @path: the full path to the key.
  * @value: the value to be written.
@@ -621,9 +621,9 @@ na_gconf_utils_write_int( GConfClient *gconf, const gchar *path, gint value, gch
  * Deprecated: 3.1
  */
 gboolean
-na_gconf_utils_write_string( GConfClient *gconf, const gchar *path, const gchar *value, gchar **message )
+fma_gconf_utils_write_string( GConfClient *gconf, const gchar *path, const gchar *value, gchar **message )
 {
-       static const gchar *thisfn = "na_gconf_utils_write_string";
+       static const gchar *thisfn = "fma_gconf_utils_write_string";
        gboolean ret = TRUE;
        GError *error = NULL;
 
@@ -642,7 +642,7 @@ na_gconf_utils_write_string( GConfClient *gconf, const gchar *path, const gchar
 }
 
 /**
- * na_gconf_utils_write_string_list:
+ * fma_gconf_utils_write_string_list:
  * @gconf: a GConfClient instance.
  * @path: the full path to the key.
  * @value: the list of values to be written.
@@ -659,9 +659,9 @@ na_gconf_utils_write_string( GConfClient *gconf, const gchar *path, const gchar
  * Deprecated: 3.1
  */
 gboolean
-na_gconf_utils_write_string_list( GConfClient *gconf, const gchar *path, GSList *value, gchar **message )
+fma_gconf_utils_write_string_list( GConfClient *gconf, const gchar *path, GSList *value, gchar **message )
 {
-       static const gchar *thisfn = "na_gconf_utils_write_string_list";
+       static const gchar *thisfn = "fma_gconf_utils_write_string_list";
        gboolean ret = TRUE;
        GError *error = NULL;
 
@@ -685,7 +685,7 @@ na_gconf_utils_write_string_list( GConfClient *gconf, const gchar *path, GSList
 }
 
 /**
- * na_gconf_utils_remove_entry:
+ * fma_gconf_utils_remove_entry:
  * @gconf: a GConfClient instance.
  * @path: the full path to the entry.
  * @message: a pointer to a gchar * which will be allocated if needed.
@@ -698,9 +698,9 @@ na_gconf_utils_write_string_list( GConfClient *gconf, const gchar *path, GSList
  * Deprecated: 3.1
  */
 gboolean
-na_gconf_utils_remove_entry( GConfClient *gconf, const gchar *path, gchar **message )
+fma_gconf_utils_remove_entry( GConfClient *gconf, const gchar *path, gchar **message )
 {
-       static const gchar *thisfn = "na_gconf_utils_remove_entry";
+       static const gchar *thisfn = "fma_gconf_utils_remove_entry";
        gboolean ret;
        GError *error = NULL;
 
@@ -723,7 +723,7 @@ na_gconf_utils_remove_entry( GConfClient *gconf, const gchar *path, gchar **mess
 }
 
 /**
- * na_gconf_utils_slist_from_string:
+ * fma_gconf_utils_slist_from_string:
  * @value: a string of the form [xxx,yyy,...] as read from GConf.
  *
  * Converts a string representing a list of strings in a GConf format
@@ -737,7 +737,7 @@ na_gconf_utils_remove_entry( GConfClient *gconf, const gchar *path, gchar **mess
  * Deprecated: 3.1
  */
 GSList *
-na_gconf_utils_slist_from_string( const gchar *value )
+fma_gconf_utils_slist_from_string( const gchar *value )
 {
        GSList *slist;
        gchar *tmp_string;
@@ -763,7 +763,7 @@ na_gconf_utils_slist_from_string( const gchar *value )
 }
 
 /**
- * na_gconf_utils_slist_to_string:
+ * fma_gconf_utils_slist_to_string:
  * @slist: a #GSList to be displayed.
  *
  * Returns: the content of @slist, with the GConf format, as a newly
@@ -773,7 +773,7 @@ na_gconf_utils_slist_from_string( const gchar *value )
  * Deprecated: 3.1
  */
 gchar *
-na_gconf_utils_slist_to_string( GSList *slist )
+fma_gconf_utils_slist_to_string( GSList *slist )
 {
        GSList *is;
        GString *str = g_string_new( "[" );
@@ -797,7 +797,7 @@ na_gconf_utils_slist_to_string( GSList *slist )
 static GConfValue *
 read_value( GConfClient *gconf, const gchar *path, gboolean use_schema, GConfValueType type )
 {
-       static const gchar *thisfn = "na_gconf_utils_read_value";
+       static const gchar *thisfn = "fma_gconf_utils_read_value";
        GError *error = NULL;
        GConfValue *value = NULL;
 
@@ -831,7 +831,7 @@ read_value( GConfClient *gconf, const gchar *path, gboolean use_schema, GConfVal
 static gboolean
 sync_gconf( GConfClient *gconf, gchar **message )
 {
-       static const gchar *thisfn = "na_gconf_utils_sync_gconf";
+       static const gchar *thisfn = "fma_gconf_utils_sync_gconf";
        gboolean ret = TRUE;
        GError *error = NULL;
 
@@ -46,20 +46,20 @@ static gboolean    sync_gconf( GConfClient *gconf, gchar **message );
  * Returns: a list of full path subdirectories.
  *
- * The returned list should be na_gconf_utils_free_subdirs() by the caller.
+ * The returned list should be fma_gconf_utils_free_subdirs() by the caller.
  *
  * Since: 2.30
@@ -75,22 +75,22 @@ na_gconf_utils_get_subdirs( GConfClient *gconf, const gchar *path )
 
 /**
- * na_gconf_utils_free_subdirs:
- * @subdirs: the subdirectory list as returned from na_gconf_utils_get_subdirs().
+ * fma_gconf_utils_free_subdirs:
+ * @subdirs: the subdirectory list as returned from fma_gconf_utils_get_subdirs().
  *
  * Release the list.
@@ -75,22 +75,22 @@ na_gconf_utils_get_subdirs( GConfClient *gconf, const gchar *path )
 
 /**
- * na_gconf_utils_has_entry:
- * @entries: the list of entries as returned by na_gconf_utils_get_entries().
+ * fma_gconf_utils_has_entry:
+ * @entries: the list of entries as returned by fma_gconf_utils_get_entries().
  * @entry: the entry to be tested.
  *
@@ -149,8 +149,8 @@ na_gconf_utils_get_entries( GConfClient *gconf, const gchar *path )
 
 /**
- * na_gconf_utils_get_bool_from_entries:
- * @entries: a list of #GConfEntry as returned by na_gconf_utils_get_entries().
+ * fma_gconf_utils_get_bool_from_entries:
+ * @entries: a list of #GConfEntry as returned by fma_gconf_utils_get_entries().
  * @entry: the searched entry.
  * @value: a pointer to a gboolean to be set to the found value.
@@ -196,8 +196,8 @@ na_gconf_utils_get_bool_from_entries( GSList *entries, const gchar *entry, gbool
 
 /**
- * na_gconf_utils_get_string_from_entries:
- * @entries: a list of #GConfEntry as returned by na_gconf_utils_get_entries().
+ * fma_gconf_utils_get_string_from_entries:
+ * @entries: a list of #GConfEntry as returned by fma_gconf_utils_get_entries().
  * @entry: the searched entry.
  * @value: a pointer to a gchar * to be set to the found value.
@@ -245,8 +245,8 @@ na_gconf_utils_get_string_from_entries( GSList *entries, const gchar *entry, gch
 
 /**
- * na_gconf_utils_get_string_list_from_entries:
- * @entries: a list of #GConfEntry as returned by na_gconf_utils_get_entries().
+ * fma_gconf_utils_get_string_list_from_entries:
+ * @entries: a list of #GConfEntry as returned by fma_gconf_utils_get_entries().
  * @entry: the searched entry.
  * @value: a pointer to a GSList * to be set to the found value.
@@ -299,15 +299,15 @@ na_gconf_utils_get_string_list_from_entries( GSList *entries, const gchar *entry
 
 /**
- * na_gconf_utils_dump_entries:
- * @entries: a list of #GConfEntry as returned by na_gconf_utils_get_entries().
+ * fma_gconf_utils_dump_entries:
+ * @entries: a list of #GConfEntry as returned by fma_gconf_utils_get_entries().
  *
  * Dumps the content of the entries.
@@ -383,22 +383,22 @@ dump_entry( GConfEntry *entry, void *user_data )
 
 /**
- * na_gconf_utils_free_entries:
- * @entries: a list of #GConfEntry as returned by na_gconf_utils_get_entries().
+ * fma_gconf_utils_free_entries:
+ * @entries: a list of #GConfEntry as returned by fma_gconf_utils_get_entries().
  *
  * Releases the provided list.